pub struct Node { /* private fields */ }Expand description
A handle to an in-memory Sui Node.
Each Node is attempted to run in isolation from each other by running them in their own tokio
runtime in a separate thread. By doing this we can ensure that all asynchronous tasks
associated with a Node are able to be stopped when desired (either when a Node is dropped or
explicitly stopped by calling Node::stop) by simply dropping that Node’s runtime.
Implementations
Sourceimpl Node
impl Node
Sourcepub fn new(config: NodeConfig) -> Self
pub fn new(config: NodeConfig) -> Self
Create a new Node from the provided NodeConfig.
The Node is returned without being started. See Node::spawn or Node::start for how to
start the node.
Sourcepub fn name(&self) -> AuthorityName
pub fn name(&self) -> AuthorityName
Return the name of this Node
pub fn config(&self) -> MutexGuard<'_, NodeConfig>
pub fn json_rpc_address(&self) -> SocketAddr
Sourcepub async fn start(&self) -> Result<()>
pub async fn start(&self) -> Result<()>
Start this Node, waiting until its completely started up.
Sourcepub fn is_running(&self) -> bool
pub fn is_running(&self) -> bool
If this Node is currently running
pub fn get_node_handle(&self) -> Option<SuiNodeHandle>
Sourcepub async fn health_check(
&self,
is_validator: bool,
) -> Result<(), HealthCheckError>
pub async fn health_check( &self, is_validator: bool, ) -> Result<(), HealthCheckError>
Perform a health check on this Node by:
- Checking that the node is running
- Calling the Node’s gRPC Health service if it’s a validator.