pub struct SwarmBuilder<R = OsRng> { /* private fields */ }Implementations
Sourceimpl SwarmBuilder
impl SwarmBuilder
Sourceimpl<R> SwarmBuilder<R>
impl<R> SwarmBuilder<R>
pub fn rng<N: RngCore + CryptoRng>(self, rng: N) -> SwarmBuilder<N>
Sourcepub fn dir<P: Into<PathBuf>>(self, dir: P) -> Self
pub fn dir<P: Into<PathBuf>>(self, dir: P) -> Self
Set the directory that should be used by the Swarm for any on-disk data.
If a directory is provided, it will not be cleaned up when the Swarm is dropped.
Defaults to using a temporary directory that will be cleaned up when the Swarm is dropped.
Sourcepub fn committee_size(self, committee_size: NonZeroUsize) -> Self
pub fn committee_size(self, committee_size: NonZeroUsize) -> Self
Set the committee size (the number of validators in the validator set).
Defaults to 1.
pub fn with_validators(self, validators: Vec<ValidatorGenesisConfig>) -> Self
pub fn with_genesis_config(self, genesis_config: GenesisConfig) -> Self
pub fn with_chain_override(self, chain: Chain) -> Self
pub fn with_num_unpruned_validators(self, n: usize) -> Self
pub fn with_jwk_fetch_interval(self, i: Duration) -> Self
pub fn with_network_config(self, network_config: NetworkConfig) -> Self
pub fn with_accounts(self, accounts: Vec<AccountConfig>) -> Self
pub fn with_objects<I: IntoIterator<Item = Object>>(self, objects: I) -> Self
pub fn with_fullnode_count(self, fullnode_count: usize) -> Self
pub fn with_fullnode_rpc_port(self, fullnode_rpc_port: u16) -> Self
pub fn with_fullnode_rpc_addr(self, fullnode_rpc_addr: SocketAddr) -> Self
pub fn with_fullnode_rpc_config(self, fullnode_rpc_config: RpcConfig) -> Self
pub fn with_fullnode_config(self, fullnode_config: NodeConfig) -> Self
pub fn with_epoch_duration_ms(self, epoch_duration_ms: u64) -> Self
pub fn with_protocol_version(self, v: ProtocolVersion) -> Self
pub fn with_supported_protocol_versions( self, c: SupportedProtocolVersions, ) -> Self
pub fn with_supported_protocol_version_callback( self, func: SupportedProtocolVersionsCallback, ) -> Self
pub fn with_supported_protocol_versions_config( self, c: ProtocolVersionsConfig, ) -> Self
pub fn with_global_state_hash_v2_enabled_config( self, c: GlobalStateHashV2EnabledConfig, ) -> Self
pub fn with_funds_withdraw_scheduler_type_config( self, c: FundsWithdrawSchedulerTypeConfig, ) -> Self
pub fn with_validator_observer_config( self, c: ValidatorObserverConfigCallback, ) -> Self
pub fn with_fullnode_supported_protocol_versions_config( self, c: ProtocolVersionsConfig, ) -> Self
pub fn with_db_checkpoint_config( self, db_checkpoint_config: DBCheckpointConfig, ) -> Self
pub fn with_execution_cache_config( self, execution_cache_config: ExecutionCacheConfig, ) -> Self
pub fn with_data_ingestion_dir(self, path: PathBuf) -> Self
pub fn with_state_sync_config(self, config: StateSyncConfig) -> Self
pub fn with_peer_deny_sync_config_per_validator( self, f: PeerDenySyncConfigCallback, ) -> Self
pub fn with_fullnode_run_with_range( self, run_with_range: Option<RunWithRange>, ) -> Self
pub fn with_fullnode_policy_config(self, config: Option<PolicyConfig>) -> Self
pub fn with_fullnode_fw_config( self, config: Option<RemoteFirewallConfig>, ) -> Self
pub fn with_disable_fullnode_pruning(self) -> Self