pub struct Swarm { /* private fields */ }Expand description
A handle to an in-memory Sui Network.
Implementations
Sourceimpl Swarm
impl Swarm
Sourcepub fn builder() -> SwarmBuilder
pub fn builder() -> SwarmBuilder
Return a new Builder
Sourcepub fn dir(&self) -> &Path
pub fn dir(&self) -> &Path
Return the path to the directory where this Swarm’s on-disk data is kept.
Sourcepub fn config(&self) -> &NetworkConfig
pub fn config(&self) -> &NetworkConfig
Return a reference to this Swarm’s NetworkConfig.
Sourcepub fn config_mut(&mut self) -> &mut NetworkConfig
pub fn config_mut(&mut self) -> &mut NetworkConfig
Return a mutable reference to this Swarm’s NetworkConfig.
pub fn all_nodes(&self) -> impl Iterator<Item = &Node>
pub fn node(&self, name: &AuthorityName) -> Option<&Node>
pub fn node_mut(&mut self, name: &AuthorityName) -> Option<&mut Node>
Sourcepub fn validator_nodes(&self) -> impl Iterator<Item = &Node>
pub fn validator_nodes(&self) -> impl Iterator<Item = &Node>
Return an iterator over shared references of all nodes that are set up as validators. This however doesn’t mean this validator is currently active (i.e. it’s not necessarily in the validator set at the moment). Note that observer fullnodes also carry a consensus config, so the intended node role is what distinguishes a validator.
pub fn validator_node_handles(&self) -> Vec<SuiNodeHandle>
Sourcepub fn active_validators(&self) -> impl Iterator<Item = &Node>
pub fn active_validators(&self) -> impl Iterator<Item = &Node>
Returns an iterator over all currently active validators.
Sourcepub fn fullnodes(&self) -> impl Iterator<Item = &Node>
pub fn fullnodes(&self) -> impl Iterator<Item = &Node>
Return an iterator over shared references of all Fullnodes.
Sourcepub fn observer_nodes(&self) -> impl Iterator<Item = &Node>
pub fn observer_nodes(&self) -> impl Iterator<Item = &Node>
Return an iterator over shared references of all fullnodes that sync as consensus observers.
pub async fn spawn_new_node(&mut self, config: NodeConfig) -> SuiNodeHandle
pub fn get_fullnode_config_builder(&self) -> FullnodeConfigBuilder